==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sk_SK">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno alebo viac zariadení</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Zobraziť v okne</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Zobraziť na celú obrazovku</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno alebo viac zariadení</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenašiel sa žiadny súborový manažér.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Inštalujte súborový manažér.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Nahrávanie sa nezačalo, nemáte dostatok voľného miesta na disku.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dosiahli ste hraničnú veľkosť pre pridelené vám miesto na disku. </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Horná hranica pre voľné miesto na disku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Nahrávanie je zastavené, nie je dosť miesta na disku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenašiel sa žiadny súborový manažér.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Inštalujte súborový manažér.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Zdrojový kód</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Preklady</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podporiť</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno alebo viac zariadení</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Oblasť</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Odísť</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zväčšenie</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Odísť</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Prevrátiť horizontálne</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Prevrátiť vertikálne</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertovať</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Stupne sivej</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Dvojfarebné, čierna a biela </translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrániť orámovanie okna</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Nastavenia kamery</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Oblasť</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Resetovanie</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zväčšenie</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočítavanie</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Veľkosť videa:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Voľné miesto na disku:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informácia</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Čas nahrávania:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Snímky</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kódek video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Zvukový kódek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávať kurzor myši</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hodina</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minúta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Spustiť stopky</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Zastaviť nahrávanie po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minúty</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Cesta k videu</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Horná hranica pre voľné miesto na disku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Zobraziť v systémovom paneli</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Čakanie v sekundách pred nahrávaním</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Kontrola aktualizácií</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Je k dispozícii</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nie je k dispozícii</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Priečinok - adresár</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertovať</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Stupne sivej</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Odoslať hlásenie</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Prehrať poslednú nahrávku</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvoriť adresár - priečinok</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimalizovať pri štarte nahrávania</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Spustiť minimalizované</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Prevrátiť horizontálne</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Prevrátiť vertikálne</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Dvojfarebné, čierna a biela </translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrániť orámovanie okna</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podporiť</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Resetovať všetky nastavenia pri nasledujúcom štarte</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright a licencie obrázkov</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Nahrávanie obrazovky</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Prehrávač</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Záznam o činnosti</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright a licencie obrázkov</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Predchádzajúce políčko</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nasledujúce políčko</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stíšiť</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Premiestniť menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/sk_SK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sk_SK">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno alebo viac zariadení</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Zobraziť v okne</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Zobraziť na celú obrazovku</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno alebo viac zariadení</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenašiel sa žiadny súborový manažér.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Inštalujte súborový manažér.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Nahrávanie sa nezačalo, nemáte dostatok voľného miesta na disku.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dosiahli ste hraničnú veľkosť pre pridelené vám miesto na disku. </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Horná hranica pre voľné miesto na disku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Nahrávanie je zastavené, nie je dosť miesta na disku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenašiel sa žiadny súborový manažér.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Inštalujte súborový manažér.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Zdrojový kód</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Preklady</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podporiť</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vyberte jedno alebo viac zariadení</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Oblasť</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Oblasť</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Odísť</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zväčšenie</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Odísť</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zväčšenie</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Prevrátiť horizontálne</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Prevrátiť vertikálne</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertovať</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Stupne sivej</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Dvojfarebné, čierna a biela </translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrániť orámovanie okna</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Nastavenia kamery</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Oblasť</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Resetovanie</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zväčšenie</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočítavanie</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Veľkosť videa:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Voľné miesto na disku:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informácia</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Čas nahrávania:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Snímky</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kódek video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Zvukový kódek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávať kurzor myši</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hodina</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minúta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Spustiť stopky</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Zastaviť nahrávanie po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minúty</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Cesta k videu</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Horná hranica pre voľné miesto na disku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Zobraziť v systémovom paneli</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Čakanie v sekundách pred nahrávaním</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Kontrola aktualizácií</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Je k dispozícii</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nie je k dispozícii</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Priečinok - adresár</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertovať</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Stupne sivej</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Odoslať hlásenie</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Prehrať poslednú nahrávku</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvoriť adresár - priečinok</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimalizovať pri štarte nahrávania</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Spustiť minimalizované</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Prevrátiť horizontálne</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Prevrátiť vertikálne</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Dvojfarebné, čierna a biela </translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrániť orámovanie okna</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Podporiť</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Resetovať všetky nastavenia pri nasledujúcom štarte</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright a licencie obrázkov</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Nahrávanie obrazovky</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Prehrávač</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Záznam o činnosti</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ON</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright a licencie obrázkov</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Predchádzajúce políčko</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nasledujúce políčko</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stíšiť</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Premiestniť menu</translation>
    </message>
</context>
</TS>
